@@ -369,7 +369,7 @@ void labeltext(int keypressed, char *clientdata)
 	 if (areastruct.selects == 1) {  /* this should be true! */
 	    short *selptr = areastruct.selectlist + areastruct.selects - 1;
 	    objinstptr selobj = SELTOOBJINST(selptr);
-	    strcpy(_STR, curlabel->string->nextpart->data.string);
+	    strcpy(selobj->thisobject->name, curlabel->string->nextpart->data.string);
 	    checkname(selobj->thisobject);
 	    undrawtext(curlabel);
 	    curlabel->string->nextpart->data.string = (char *)realloc(
