@@ -34,6 +34,7 @@
 #include "Xw/Xw.h"
 #include "Xw/WorkSpace.h"
 #include "Xw/TextEdit.h"
+#include "Xw/Toggle.h"
 
 /*-------------------------------------------------------------------------*/
 /* Local includes							   */
@@ -72,8 +73,8 @@ short    flstart, flfiles, flcurrent;
 int	 flcurwidth;
 
 GC	 hgc = NULL, sgc = NULL;
-char     **filenames = NULL;
 char	 *cwdname = NULL;
+fileliststruct *files;
 
 /*-------------------------------------------------------------------------*/
 /* Compare two filenames (for use by qsort())				   */
@@ -81,7 +82,8 @@ char	 *cwdname = NULL;
 
 int fcompare(const void *a, const void *b)
 {
-   return(strcmp(*((char **)a), *((char **)b)));
+   return (strcmp((char *)(((fileliststruct *)a)->filename),
+	(char *)(((fileliststruct *)b)->filename)));
 }
 
 /*-------------------------------------------------------------------------*/
@@ -105,8 +107,8 @@ void dragfilebox(Widget w, caddr_t clientdata, XMotionEvent *event)
 	   10 + FILECHARHEIGHT * (flcurrent
 	   - flstart), flcurwidth + 10, FILECHARHEIGHT);
 
-   twidth = XTextWidth(appdata.filefont, filenames[filenum],
-	    strlen(filenames[filenum]));
+   twidth = XTextWidth(appdata.filefont, files[filenum].filename,
+	    strlen(files[filenum].filename));
    XDrawRectangle(dpy, lwin, areastruct.gc, 5,
 	   10 + FILECHARHEIGHT * (filenum
 	   - flstart), twidth + 10, FILECHARHEIGHT);
@@ -245,15 +247,31 @@ void findcrashfiles()
    }
 }  
 
-/*-------------------------------------------------------------------------*/
-/* Make a list of the files in the list widget window			   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Match a filename extension against the file filter string.		*/
+/*----------------------------------------------------------------------*/
 
-void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
+Boolean match_filter(char *fname, char *filter)
+{
+   char *dotptr = strrchr(fname, '.');
+
+   if ((dotptr != NULL) && (filter != NULL) &&
+       (filter[0] != '\0') && (strstr(dotptr, filter) != NULL))
+      return True;
+
+   return False;
+}
+
+/*----------------------------------------------------------------------*/
+/* Make a list of the files in the list widget window			*/
+/*----------------------------------------------------------------------*/
+
+void listfiles(Widget w, popupstruct *okaystruct, caddr_t calldata)
 {
    XGCValues	values;
    Arg wargs[2];
    DIR *cwd;
+   char *filter;
    Window lwin = XtWindow(w);
    short allocd = INITDIRS;
    short n = 0;
@@ -262,6 +280,8 @@ void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
    int pixheight;
    Dimension textwidth, textheight;
 
+   filter = okaystruct->filter;
+
    if (sgc == NULL) {
       values.foreground = FOREGROUND;
       values.font = appdata.filefont->fid;
@@ -279,8 +299,8 @@ void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
 
       /* get list of files in the current directory (cwd) */
 
-      if (filenames == NULL) 
-         filenames = (char **) malloc (INITDIRS * sizeof(char *));
+      if (files == NULL) 
+         files = (fileliststruct *) malloc (INITDIRS * sizeof(fileliststruct));
       flfiles = 0;
       if (cwdname == NULL) {
 	 cwdname = (char *) malloc (sizeof(char));
@@ -310,20 +330,41 @@ void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
          while ((dp = readdir(cwd)) != NULL) {
 	    /* don't put current directory in list */
 	    if (!strcmp(dp->d_name, ".")) continue;
-	    filenames[flfiles] = (char *) malloc ((strlen(dp->d_name) + 2) *
-		 sizeof(char));
-	    strcpy(filenames[flfiles++], dp->d_name);
-	    if (flfiles == allocd) {
+
+	    /* record the type of file */
+	
+	    sprintf(_STR2, "%s%s", cwdname, dp->d_name); 
+	    stat(_STR2, &statbuf);
+	    if ((statbuf.st_mode & S_IFDIR) != 0) /* is a directory */
+	       files[flfiles].filetype = DIRECTORY;
+	    else if (match_filter(dp->d_name, filter))
+	       files[flfiles].filetype = MATCH;
+	    else {
+	       if (areastruct.filefilter)
+		  continue;
+	       else
+	          files[flfiles].filetype = NONMATCH;
+	    }
+
+	    /* save the filename */
+
+	    files[flfiles].filename = (char *) malloc ((strlen(dp->d_name) + 
+		 ((files[flfiles].filetype == DIRECTORY) ? 2 : 1)) * sizeof(char));
+	    strcpy(files[flfiles].filename, dp->d_name);
+	    if (files[flfiles].filetype == DIRECTORY)
+	       strcat(files[flfiles].filename, "/");
+	    if (++flfiles == allocd) {
 	       allocd += INITDIRS;
-	       filenames = (char **) realloc (filenames, allocd * sizeof(char *));
+	       files = (fileliststruct *) realloc(files,
+			allocd * sizeof(fileliststruct));
 	    }
          }
       }
       closedir(cwd);
 
-      /* sort the filenames[] array into alphabetical order (like "ls") */
+      /* sort the files[] array into alphabetical order (like "ls") */
 
-      qsort((void *)filenames, (size_t)flfiles, sizeof(char *), fcompare);
+      qsort((void *)files, (size_t)flfiles, sizeof(fileliststruct), fcompare);
 
       pixheight = flfiles * FILECHARHEIGHT + 20;
 
@@ -336,16 +377,19 @@ void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
       XFillRectangle(dpy, flistpix, sgc, 0, 0, textwidth, pixheight);
       XSetForeground(dpy, sgc, FOREGROUND);
       for (n = 0; n < flfiles; n++) {
-	 sprintf(_STR2, "%s%s", cwdname, filenames[n]); 
-	 stat(_STR2, &statbuf);
-	 if ((statbuf.st_mode & S_IFDIR) != 0) {  /* is a directory */
-	    XSetForeground(dpy, sgc, SELECTCOLOR);
-	    strcat(filenames[n], "/");
+	 switch (files[n].filetype) {
+	    case DIRECTORY:
+	       XSetForeground(dpy, sgc, SELECTCOLOR);
+	       break;
+	    case MATCH:
+	       XSetForeground(dpy, sgc, FILTERCOLOR);
+	       break;
+	    case NONMATCH:
+	       XSetForeground(dpy, sgc, FOREGROUND);
+	       break;
 	 }
          XDrawString(dpy, flistpix, sgc, 10, 10 + FILECHARASCENT + n * FILECHARHEIGHT,
-	    filenames[n], strlen(filenames[n]));
-	 if ((statbuf.st_mode & S_IFDIR) != 0)
-	    XSetForeground(dpy, sgc, FOREGROUND);
+	    files[n].filename, strlen(files[n].filename));
       }
    }
 
@@ -362,18 +406,19 @@ void listfiles(Widget w, caddr_t clientdata, caddr_t calldata)
 /* size accordingly.							   */
 /*-------------------------------------------------------------------------*/
 
-void newfilelist(Widget w, Widget textw)
+void newfilelist(Widget w, popupstruct *okaystruct)
 {
    short n;
+   Widget textw = okaystruct->textw;
 
    for (n = 0; n < flfiles; n++)
-      free(filenames[n]);
-   free(filenames);
+      free(files[n].filename);
+   free(files);
    if (flistpix != (Pixmap)NULL) XFreePixmap(dpy, flistpix);
-   filenames = NULL;
+   files = NULL;
    flistpix = (Pixmap)NULL;
    flstart = 0;
-   listfiles(w, NULL, NULL);
+   listfiles(w, okaystruct, NULL);
    showlscroll(XtNameToWidget(XtParent(w), "LScroll"), NULL, NULL);
    XwTextClearBuffer(textw);
    XwTextInsert(textw, cwdname);
@@ -384,13 +429,14 @@ void newfilelist(Widget w, Widget textw)
 /* Button press handler for file list window				   */
 /*-------------------------------------------------------------------------*/
 
-void fileselect(Widget w, Widget textw, XButtonEvent *event)
+void fileselect(Widget w, popupstruct *okaystruct, XButtonEvent *event)
 {
    Arg wargs[2];
    Window lwin = XtWindow(w);
    Dimension textwidth, textheight;
    short filenum, n = 0;
    char *tbuf;
+   Widget textw = okaystruct->textw;
 
    flcurrent = -1;
 
@@ -401,7 +447,7 @@ void fileselect(Widget w, Widget textw, XButtonEvent *event)
    /* third mouse button cancels selection and reverts buffer to cwd name */
 
    if (event->button == Button3) {
-      newfilelist(w, textw);
+      newfilelist(w, okaystruct);
       return;
    }
 
@@ -412,26 +458,26 @@ void fileselect(Widget w, Widget textw, XButtonEvent *event)
    /* Attempt to enter invalid directory. . . treat like button 3 */
 
    if (filenum < 0) {
-      newfilelist(w, textw);
+      newfilelist(w, okaystruct);
       return;
    }
    
    /* check if this file is a directory or not */
 
-   if (strchr(filenames[filenum], '/') == NULL)	{
+   if (strchr(files[filenum].filename, '/') == NULL)	{
 
       /* highlight the entry. . . */
 
       XSetForeground(dpy, sgc, AUXCOLOR);
       XDrawString(dpy, flistpix, sgc, 10, 10 + FILECHARASCENT + filenum * FILECHARHEIGHT,
-   	   filenames[filenum], strlen(filenames[filenum]));
+   	   files[filenum].filename, strlen(files[filenum].filename));
       XCopyArea(dpy, flistpix, lwin, sgc, 0, flstart * FILECHARHEIGHT,
 	   textwidth, textheight, 0, 0);
 
       /* . . .and append it to the text field */
 
       tbuf = (char *)malloc((XwTextGetLastPos(textw)
-	     + strlen(filenames[filenum]) + 5) * sizeof(char));
+	     + strlen(files[filenum].filename) + 5) * sizeof(char));
       strcpy(tbuf, (char *)XwTextCopyBuffer(textw)); 
 
       /* add a comma if there is already text in the destination buffer */
@@ -443,12 +489,12 @@ void fileselect(Widget w, Widget textw, XButtonEvent *event)
 	 if (cwdname != NULL) {
 	    if (cwdname[0] != '\0') {
 	       tbuf = (char *)realloc(tbuf, (strlen(cwdname) +
-			strlen(filenames[filenum]) + 5) * sizeof(char));
+			strlen(files[filenum].filename) + 5) * sizeof(char));
 	       strcpy(tbuf, cwdname);
 	    }
  	 }
       }
-      strcat(tbuf, filenames[filenum]);
+      strcat(tbuf, files[filenum].filename);
       XwTextClearBuffer(textw);
       XwTextInsert(textw, tbuf);
       XwTextResize(textw);
@@ -456,7 +502,7 @@ void fileselect(Widget w, Widget textw, XButtonEvent *event)
    }
    else {  /* move to new directory */
 
-      if (!strcmp(filenames[filenum], "../")) {
+      if (!strcmp(files[filenum].filename, "../")) {
          char *cptr, *sptr = cwdname;
 	 if (!strcmp(cwdname, "/")) return;	/* no way up from root dir. */
 	 while(strstr(sptr, "../") != NULL) sptr += 3;
@@ -473,10 +519,10 @@ void fileselect(Widget w, Widget textw, XButtonEvent *event)
       }
       else {
 	 cwdname = (char *)realloc(cwdname, (strlen(cwdname) +
-	        strlen(filenames[filenum]) + 1) * sizeof(char));
-         strcat(cwdname, filenames[filenum]);
+	        strlen(files[filenum].filename) + 1) * sizeof(char));
+         strcat(cwdname, files[filenum].filename);
       }
-      newfilelist(w, textw);
+      newfilelist(w, okaystruct);
    }
 }
 
@@ -517,12 +563,13 @@ void showlscroll(Widget w, caddr_t clientdata, caddr_t calldata)
 /* Button Motion handler for moving the scrollbar up and down		   */
 /*-------------------------------------------------------------------------*/
 
-void draglscroll(Widget w, Widget filew, XButtonEvent *event)
+void draglscroll(Widget w, popupstruct *okaystruct, XButtonEvent *event)
 {
    Arg wargs[2];
    Dimension swidth, sheight;
    int phheight, finscr, flsave = flstart;
    short n = 0;
+   Widget filew = okaystruct->filew;
 
    XtnSetArg(XtNwidth, &swidth);
    XtnSetArg(XtNheight, &sheight);
@@ -539,19 +586,33 @@ void draglscroll(Widget w, Widget filew, XButtonEvent *event)
 
    if (flstart != flsave) {
       showlscroll(w, NULL, NULL);
-      listfiles(filew, NULL, NULL); 
+      listfiles(filew, okaystruct, NULL); 
    }
 }
 
-/*-------------------------------------------------------------------------*/
-/* Generate the file list window					   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Set/unset the file filtering function				*/
+/*----------------------------------------------------------------------*/
 
-void genfilelist(Widget parent, Widget entertext, Dimension width)
+void setfilefilter(Widget w, popupstruct *okaystruct, caddr_t calldata)
+{
+   areastruct.filefilter = (areastruct.filefilter) ? False : True;
+
+   /* Force regeneration of the file list */
+
+   newfilelist(okaystruct->filew, okaystruct);
+}
+
+/*----------------------------------------------------------------------*/
+/* Generate the file list window					*/
+/*----------------------------------------------------------------------*/
+
+void genfilelist(Widget parent, popupstruct *okaystruct, Dimension width)
 {
    Arg		wargs[8];
-   Widget 	listarea, lscroll;
+   Widget 	listarea, lscroll, entertext, dofilter;
    short 	n = 0;
+   int		wwidth;
 
    XtnSetArg(XtNx, 20);
    XtnSetArg(XtNy, FILECHARHEIGHT - 10);
@@ -559,16 +620,18 @@ void genfilelist(Widget parent, Widget entertext, Dimension width)
    XtnSetArg(XtNheight, LISTHEIGHT - FILECHARHEIGHT);
    XtnSetArg(XtNfont, appdata.filefont);
 
+   entertext = okaystruct->textw;
    listarea = XtCreateManagedWidget("Filelist", XwworkSpaceWidgetClass,
 	  parent, wargs, n); n = 0;
-   XtAddCallback(listarea, XtNexpose, (XtCallbackProc)listfiles, NULL);
+   XtAddCallback(listarea, XtNexpose, (XtCallbackProc)listfiles, okaystruct);
    XtAddEventHandler(listarea, ButtonPressMask, False,
-	  (XtEventHandler)fileselect, entertext);
+	  (XtEventHandler)fileselect, okaystruct);
    XtAddEventHandler(listarea, EnterWindowMask, False,
 	  (XtEventHandler)startfiletrack, NULL);
    XtAddEventHandler(listarea, LeaveWindowMask, False,
 	  (XtEventHandler)endfiletrack, NULL);
    flstart = 0;
+   okaystruct->filew = listarea;
 
    XtnSetArg(XtNx, width - SBARSIZE - 20);
    XtnSetArg(XtNy, FILECHARHEIGHT - 10);
@@ -581,7 +644,27 @@ void genfilelist(Widget parent, Widget entertext, Dimension width)
 
    XtAddCallback(lscroll, XtNexpose, (XtCallbackProc)showlscroll, NULL);
    XtAddEventHandler(lscroll, Button1MotionMask | Button2MotionMask,
-	     False, (XtEventHandler)draglscroll, listarea);
+	     False, (XtEventHandler)draglscroll, okaystruct);
+
+   /* Add a toggle widget to turn file filtering on/off */
+
+   wwidth = XTextWidth(appdata.xcfont, "filter", strlen("filter"));
+   XtnSetArg(XtNx, width - wwidth - 50);
+   XtnSetArg(XtNy, LISTHEIGHT + 10);
+   XtnSetArg(XtNset, areastruct.filefilter);
+   XtnSetArg(XtNsquare, True);
+   XtnSetArg(XtNborderWidth, 0);
+   XtnSetArg(XtNfont, appdata.xcfont);
+   XtnSetArg(XtNlabelLocation, XwLEFT);
+   dofilter = XtCreateManagedWidget("Filter", XwtoggleWidgetClass,
+		parent, wargs, n); n = 0;
+   XtAddCallback(dofilter, XtNselect, (XtCallbackProc)setfilefilter, okaystruct);
+   XtAddCallback(dofilter, XtNrelease, (XtCallbackProc)setfilefilter, okaystruct);
+
+   /* force new file list, in case the highlight filter changed */
+
+   if (flistpix != (Pixmap)NULL) XFreePixmap(dpy, flistpix);
+   flistpix = (Pixmap)NULL;
 }
 
 /*-------------------------------------------------------------------------*/
