@@ -957,7 +957,7 @@ void copycat()
 
       /* give the new object a unique name */
 
-      sprintf(_STR, "_%s", oldobj->name);
+      sprintf((*newobj)->name, "_%s", oldobj->name);
       checkname(*newobj);
 
       /* copy other object properties */
