@@ -2430,9 +2430,12 @@ void pyhierarchy(objectptr cschem, CalllistPtr cfrom, PyObject *cktlist)
 
       for (i = 0; i < cschem->num_params; i++) {
 	 paramlist = *(cschem->params + i);
-	 if (paramlist->type == XC_SHORT)
+	 if (paramlist->type == XC_INT)
 	    PyList_Append(pyparams,
-			PyInt_FromLong((long)paramlist->parameter.svalue));
+			PyInt_FromLong((long)paramlist->parameter.ivalue));
+	 if (paramlist->type == XC_FLOAT)
+	    PyList_Append(pyparams,
+			PyFloat_FromDouble((double)paramlist->parameter.fvalue));
 	 else if (paramlist->type == XC_STRING)
 	    PyList_Append(pyparams,
 			PyGetStringParts(paramlist->parameter.string));
@@ -2457,9 +2460,12 @@ void pyhierarchy(objectptr cschem, CalllistPtr cfrom, PyObject *cktlist)
 
 	    for (i = 0; i < calllist->callobj->num_params; i++) {
 	       paramlist = *(calllist->callinst->params + i);
-	       if (paramlist->type == XC_SHORT)
+	       if (paramlist->type == XC_INT)
 	          PyList_Append(pyparams,
-			PyInt_FromLong((long)paramlist->parameter.svalue));
+			PyInt_FromLong((long)paramlist->parameter.ivalue));
+	       else if (paramlist->type == XC_FLOAT)
+	          PyList_Append(pyparams,
+			PyFloat_FromDouble((double)paramlist->parameter.fvalue));
 	       else if (paramlist->type == XC_STRING)
 	          PyList_Append(pyparams,
 			PyGetStringParts(paramlist->parameter.string));
@@ -2601,7 +2607,7 @@ void writepcb(objectptr cschem, CalllistPtr cfrom, char *prefix, char *mode)
    struct Ptab *hidx, *htmp;
    struct Pstr *tmpstr;
    struct Pnet *tmpnet;
-   objinstptr cinst = (cfrom == NULL) ? NULL : cfrom->callinst;
+   objinstptr cinst;
    int locnet;
 
    /* Step 1:  Go through the netlist of this object and add any new nets to	*/
@@ -2644,6 +2650,7 @@ void writepcb(objectptr cschem, CalllistPtr cfrom, char *prefix, char *mode)
    /* Step 2:  Go through the list of calls to search for endpoints */
 
    for (calllist = cschem->calllist; calllist != NULL; calllist = calllist->next) {
+      cinst = calllist->callinst;
 
       /* Step 3:  If call is to a bottom-most schematic, output the device connections */
       /* Info-label can provide an alternate name or specify the instance number */
