@@ -169,23 +169,27 @@ void setparammarks(genericptr thiselem)
    }
 }
 
-/*--------------------------------------------------------*/
-/* Make numerical parameter substitutions into an element */
-/*--------------------------------------------------------*/
+/*------------------------------------------------------*/
+/* Make numerical parameter substitutions into an	*/
+/* element.  "thisinst" may be NULL, in which case all	*/
+/* default values are used in the substitution.		*/ 
+/*							*/
+/* Return values:					*/
+/*   -1 if the instance declares no parameters		*/
+/*    0 if parameters do not change the instance's bbox */
+/*    1 if parameters change instance's bbox		*/
+/*    2 if parameters change instance's netlist		*/
+/*------------------------------------------------------*/
 
-void psubstitute(objinstptr thisinst)
+int opsubstitute(objectptr thisobj, objinstptr pinst)
 {
    genericptr *eptr, thiselem;
    int i, j, k, ival;
    float fval;
    oparamptr ops, ips;
    XPoint *setpt;
-   objinstptr pinst;
-   objectptr thisobj;
    Boolean needrecalc;	/* for arcs and splines */
-
-   pinst = (thisinst == areastruct.topobject) ? NORMINST : thisinst;
-   thisobj = (pinst == NULL) ? objectdata : pinst->thisobject;
+   int retval = -1;
 
    for (eptr = thisobj->plist; eptr < thisobj->plist + thisobj->parts; eptr++) {
 
@@ -207,6 +211,7 @@ void psubstitute(objinstptr thisinst)
 
          switch(ops->which) {
 	    case P_POSITION_X:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case POLYGON:
 	             setpt = TOPOLY(&thiselem)->points + k;
@@ -228,6 +233,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_POSITION_Y:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case POLYGON:
 	             setpt = TOPOLY(&thiselem)->points + k;
@@ -249,6 +255,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_STYLE:
+	       retval = max(retval, 0);
 	       switch(thiselem->type) {
 	          case POLYGON:
 		     TOPOLY(&thiselem)->style = ival;
@@ -265,6 +272,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_JUSTIFY:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case LABEL:
 		     TOLABEL(&thiselem)->justify = ival;
@@ -272,6 +280,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_ANGLE1:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case ARC:
 		     TOARC(&thiselem)->angle1 = fval;
@@ -280,6 +289,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_ANGLE2:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case ARC:
 		     TOARC(&thiselem)->angle1 = fval;
@@ -288,6 +298,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_RADIUS:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case ARC:
 		     TOARC(&thiselem)->radius = ival;
@@ -297,6 +308,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_MINOR_AXIS:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case ARC:
 		     TOARC(&thiselem)->yaxis = ival;
@@ -305,6 +317,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_ROTATION:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case LABEL:
 		     TOLABEL(&thiselem)->rotation = ival;
@@ -315,6 +328,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_SCALE:
+	       retval = max(retval, 1);
 	       switch(thiselem->type) {
 	          case LABEL:
 		     TOLABEL(&thiselem)->scale = fval;
@@ -325,6 +339,7 @@ void psubstitute(objinstptr thisinst)
 	       }
 	       break;
 	    case P_LINEWIDTH:
+	       retval = max(retval, 0);
 	       switch(thiselem->type) {
 	          case POLYGON:
 		     TOPOLY(&thiselem)->width = fval;
@@ -356,6 +371,24 @@ void psubstitute(objinstptr thisinst)
 	 }
       }
    }
+   return retval;
+}
+
+/*------------------------------------------------------*/
+/* Same as above, but determines the object from
+/*------------------------------------------------------*/
+
+int psubstitute(objinstptr thisinst)
+{
+   objinstptr pinst;
+   objectptr thisobj;
+
+   pinst = (thisinst == areastruct.topobject) ? NORMINST : thisinst;
+   if (pinst == NULL) return -1;		/* there is no instance */
+   else if (pinst->params == NULL) return -1;	/* instance has no parameters */
+
+   thisobj = (pinst == NULL) ? objectdata : pinst->thisobject;
+   return opsubstitute(thisobj, pinst);
 }
 
 /*------------------------------------------------------*/
@@ -407,42 +440,42 @@ void pwriteback(objinstptr thisinst)
          switch(ops->which) {
 	    case P_POSITION_X:
 	       switch(thiselem->type) {
-	          case POLYGON:
-	             setpt = TOPOLY(&thiselem)->points + k;
-		     *ival = setpt->x;
-		     break;
-	          case SPLINE:
-		     *ival = TOSPLINE(&thiselem)->ctrl[k].x;
+	          case OBJECT:
+		     *ival = TOOBJINST(&thiselem)->position.x;
 		     break;
 	          case LABEL:
 		     *ival = TOLABEL(&thiselem)->position.x;
 		     break;
-	          case OBJECT:
-		     *ival = TOOBJINST(&thiselem)->position.x;
+	          case POLYGON:
+	             setpt = TOPOLY(&thiselem)->points + k;
+		     *ival = setpt->x;
 		     break;
 	          case ARC:
 		     *ival = TOARC(&thiselem)->position.x;
 		     break;
+	          case SPLINE:
+		     *ival = TOSPLINE(&thiselem)->ctrl[k].x;
+		     break;
 	       }
 	       break;
 	    case P_POSITION_Y:
 	       switch(thiselem->type) {
-	          case POLYGON:
-	             setpt = TOPOLY(&thiselem)->points + k;
-		     *ival = setpt->y;
-		     break;
-	          case SPLINE:
-		     *ival = TOSPLINE(&thiselem)->ctrl[k].y;
+	          case OBJECT:
+		     *ival = TOOBJINST(&thiselem)->position.y;
 		     break;
 	          case LABEL:
 		     *ival = TOLABEL(&thiselem)->position.y;
 		     break;
-	          case OBJECT:
-		     *ival = TOOBJINST(&thiselem)->position.y;
+	          case POLYGON:
+	             setpt = TOPOLY(&thiselem)->points + k;
+		     *ival = setpt->y;
 		     break;
 	          case ARC:
 		     *ival = TOARC(&thiselem)->position.y;
 		     break;
+	          case SPLINE:
+		     *ival = TOSPLINE(&thiselem)->ctrl[k].y;
+		     break;
 	       }
 	       break;
 	    case P_STYLE:
@@ -450,12 +483,12 @@ void pwriteback(objinstptr thisinst)
 	          case POLYGON:
 		     *ival = TOPOLY(&thiselem)->style;
 		     break;
-	          case SPLINE:
-		     *ival = TOSPLINE(&thiselem)->style;
-		     break;
 	          case ARC:
 		     *ival = TOARC(&thiselem)->style;
 		     break;
+	          case SPLINE:
+		     *ival = TOSPLINE(&thiselem)->style;
+		     break;
 	          case PATH:
 		     *ival = TOPATH(&thiselem)->style;
 		     break;
@@ -498,22 +531,22 @@ void pwriteback(objinstptr thisinst)
 	       break;
 	    case P_ROTATION:
 	       switch(thiselem->type) {
-	          case LABEL:
-		     *ival = TOLABEL(&thiselem)->rotation;
-		     break;
 	          case OBJECT:
 		     *ival = TOOBJINST(&thiselem)->rotation;
 		     break;
+	          case LABEL:
+		     *ival = TOLABEL(&thiselem)->rotation;
+		     break;
 	       }
 	       break;
 	    case P_SCALE:
 	       switch(thiselem->type) {
-	          case LABEL:
-		     *fval = TOLABEL(&thiselem)->scale;
-		     break;
 	          case OBJECT:
 		     *fval = TOOBJINST(&thiselem)->scale;
 		     break;
+	          case LABEL:
+		     *fval = TOLABEL(&thiselem)->scale;
+		     break;
 	       }
 	       break;
 	    case P_LINEWIDTH:
@@ -521,12 +554,12 @@ void pwriteback(objinstptr thisinst)
 	          case POLYGON:
 		     *fval = TOPOLY(&thiselem)->width;
 		     break;
-	          case SPLINE:
-		     *fval = TOSPLINE(&thiselem)->width;
-		     break;
 	          case ARC:
 		     *fval = TOARC(&thiselem)->width;
 		     break;
+	          case SPLINE:
+		     *fval = TOSPLINE(&thiselem)->width;
+		     break;
 	          case PATH:
 		     *fval = TOPATH(&thiselem)->width;
 		     break;
@@ -1280,13 +1313,18 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
 
 void unparameterize(u_int mode)
 {
-   short *fselect, ptype = (short)param_select[mode];
+   short *fselect, ptype;
    int locpos;
    stringpart *strptr, *tmpptr, *lastptr;
    labelptr settext;
 
-   if (!checkselect(ptype)) objectselect(ptype);
-   if (!checkselect(ptype)) return;
+   if (mode >= 0) {
+      ptype = (short)param_select[mode];
+      if (!checkselect(ptype)) objectselect(ptype);
+      if (!checkselect(ptype)) return;
+   }
+   else
+      ptype = SEL_ANY;
 
    if ((areastruct.selects == 1) && (ptype & LABEL) && textend > 0
 		&& textend < textpos) {
@@ -1336,11 +1374,17 @@ void unparameterize(u_int mode)
 
 void parameterize(u_int mode)
 {
-   short *fselect, ptype = (short)param_select[mode];
+   short *fselect, ptype;
    labelptr settext;
 
-   if (!checkselect(ptype)) objectselect(ptype);
-   if (!checkselect(ptype)) return;
+   if (mode >= 0) {
+      ptype = (short)param_select[mode];
+      if (!checkselect(ptype)) objectselect(ptype);
+      if (!checkselect(ptype)) return;
+   }
+   else
+      ptype = SEL_ANY;
+
    for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
             areastruct.selects; fselect++) {
       if ((mode == P_SUBSTRING) && (areastruct.selects == 1) &&
