@@ -107,7 +107,7 @@ extern void objectdelete(short);
 extern void deletebutton(XButtonEvent *);
 extern short xc_undelete(Widget, u_int, XButtonEvent *);
 extern void printname(objectptr);
-extern void checkname(objectptr);
+extern Boolean checkname(objectptr);
 extern objectptr finddot();
 extern void movepoints(genericptr *, short, short);
 extern void domakeobject(Widget, caddr_t);
@@ -498,7 +498,8 @@ extern void parameterize(u_int);
 extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
-extern void psubstitute(objinstptr);
+extern int opsubstitute(objectptr, objinstptr);
+extern int psubstitute(objinstptr);
 extern void pwriteback(objinstptr);
 extern short paramlen(u_char *);
 extern int natstrlen(u_char *);
