@@ -783,7 +783,7 @@ void makesymbol(Widget w, caddr_t calldata)
 {
    /* copy name from popup prompt buffer and check */
 
-   strcpy(_STR, _STR2);
+   strcpy(objectdata->name, _STR2);
    checkname(objectdata);
    swapschem(w, (u_int)1, calldata);
 }
