@@ -280,58 +280,66 @@ static char * fi_xpm[] = {
 " X..X..X........... ",
 "                    "};
 /* XPM */
-static char * hf_xpm[] = {
-"20 20 4 1",
-" 	c #FFFFFFFFFFFF",
-".	c #000000000000",
-"X	c #B6DAB2CAB6DA",
-"o	c #79E77DF779E7",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"    .   .  .   .    ",
-" Xo......  ......oX ",
-" Xo......  ......oX ",
-"    .   .  .   .    ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        ",
-"        .  .        "};
+static char * fx_xpm[] = {
+"20 20 8 1",
+" 	c #FFFF00000000",
+".	c #FFFFA3A3A3A3",
+"X	c #FFFFFFFFFFFF",
+"o	c #FFFFFFFF0000",
+"O	c #FFFFD7D70000",
+"+	c #C1C1C6C6FFFF",
+"@	c #00000000FFFF",
+"#	c #8E8E9999FFFF",
+"       .XXXXXXXXXXXX",
+" oooooO  XX++XXXXXXX",
+".Ooooooo .X@@@XXXXXX",
+"X ooooooO X+#@@XXXXX",
+"X OooooooO XXX@#X#XX",
+"X OooooooO XXXX@#+XX",
+"X ooooooO XXX+@@@+XX",
+".Ooooooo .XXXXX@@+XX",
+" oooooO  XXXXXXX@+XX",
+"       .XXXXXXXXX+XX",
+"XXXXXXXXXXXX.       ",
+"XXXXXXXXXXX  oooooo ",
+"XXXXXXXXXX. ooooooO.",
+"XXXXXXXXXX Ooooooo X",
+"XXXXXXXXX OooooooO X",
+"XXXXXXXXX OooooooO X",
+"XXXXXXXXXX Ooooooo X",
+"XXXXXXXXXX. ooooooO.",
+"XXXXXXXXXXX  Oooooo ",
+"XXXXXXXXXXXX.       "};
 /* XPM */
-static char * j4_xpm[] = {
-"20 20 3 1",
-" 	c #1861FFFF2081",
-".	c #FFFFFFFFFFFF",
-"X	c #2081B2CA1040",
-" .................. ",
-" .................. ",
-" .................. ",
-" .................. ",
-" ..X............X.. ",
-" ..XX..........XX.. ",
-" ..XXX........XXX.. ",
-" ..XXXX......XXXX.. ",
-"XXXXXXXX....XXXXXXXX",
-"XXXXXXXXX..XXXXXXXXX",
-"XXXXXXXX....XXXXXXXX",
-" ..XXXX......XXXX.. ",
-" ..XXX........XXX.. ",
-" ..XX..........XX.. ",
-" ..X............X.. ",
-" .................. ",
-" .................. ",
-" .................. ",
-" .................. ",
-" .................. "};
+static char * pz_xpm[] = {
+"20 20 7 1",
+" 	c #B0B0FFFF4C4C",
+".	c #C0C0C0C0C0C0",
+"X	c #000000000000",
+"o	c #FFFFFFFF0000",
+"O	c #7F7F7F7F0000",
+"+	c #B2B2BFBF1515",
+"@	c #808080808080",
+"      .X X.         ",
+"        X    XXX.   ",
+"       XoX. XoooX.  ",
+"      XXooX OooooX  ",
+"        +ooXoooo+@  ",
+".   X   Xoo+ooooX   ",
+"X  X@.  Ooooo@XX    ",
+" X@ooXOOoooooX     .",
+".@Xooo+oooooo.X   .X",
+"X  Xoooooooooo.X .X ",
+"    X+ooooOXXooo@X  ",
+"     XoooO   XoX  X ",
+"  XXO+oooX    X    X",
+" XooooOooX   O     .",
+" XoooX +o+XO       X",
+" X+ooX Xoo@       X ",
+"  XX@  .@X       X  ",
+"        X        X  ",
+"      .X.O  XX    . ",
+"     .X   OX  X   XX"};
 /* XPM */
 static char * li_xpm[] = {
 "20 20 8 1",
@@ -541,57 +549,64 @@ static char * t_xpm[] = {
 "+ooooo+     Xoooooo."};
 /* XPM */
 static char * uj_xpm[] = {
-"20 20 3 1",
-" 	c #FFFFFFFFFFFF",
-".	c #000000000000",
-"X	c #2081B2CA1040",
-"         .          ",
-"         .          ",
-"         .          ",
-"         .          ",
-"     X   .    X     ",
-"    XX   .    XX    ",
-"   XXX   .    XXX   ",
-"  XXXX   .    XXXX  ",
-" XXXXXXXX.XXXXXXXXX ",
-"XXXXXXXXXXXXXXXXXXXX",
-" XXXXXXXXX.XXXXXXXX ",
-"  XXXX    .   XXXX  ",
-"   XXX    .   XXX   ",
-"    XX    .   XX    ",
-"     X    .   X     ",
-"          .         ",
-"          .         ",
-"          .         ",
-"          .         ",
-"          .         "};
+"20 20 6 1",
+" 	c #B0B0FFFF4C4C",
+".	c #7F7F7F7F0000",
+"X	c #000000000000",
+"o	c #8484B3B31111",
+"O	c #C0C0C0C0C0C0",
+"+	c #808080808080",
+"    ..   Xo         ",
+".       Xo    ..    ",
+" .     oXX   XXX.   ",
+" X    oXXXX oXXXX   ",
+".X     ooXXXoXXXX   ",
+"    X    XXXXXXXo   ",
+"   XX    XXXXXoo    ",
+". XXX.  XXXXXX     O",
+" X.XXXXXXXXXXXX   OX",
+"X  oXXXXXXXXXXXX OX ",
+"    oXXXXX+oXXXX+X  ",
+"     XXXX+   XXX  X ",
+"  oXXXXXXo    X    X",
+" XXXXXoXXo   o     O",
+" XXXXX XXXXo     ooX",
+" oXXX  .XXX      oX ",
+"  oXo   oX       o  ",
+"        X        X  ",
+"      OXX  oXX    O ",
+"     OX .X X  X   XX"};
 /* XPM */
-static char * vf_xpm[] = {
-"20 20 4 1",
+static char * fy_xpm[] = {
+"20 20 8 1",
 " 	c #FFFFFFFFFFFF",
-".	c #B6DAB2CAB6DA",
-"X	c #79E77DF779E7",
-"o	c #000000000000",
-"                    ",
-"         ..         ",
-"         XX         ",
-"         oo         ",
-"        oooo        ",
-"         oo         ",
-"         oo         ",
-"         oo         ",
-"oooooooooooooooooooo",
-"                    ",
-"                    ",
-"oooooooooooooooooooo",
-"         oo         ",
-"         oo         ",
-"         oo         ",
-"        oooo        ",
-"         oo         ",
-"         XX         ",
-"         ..         ",
-"                    "};
+".	c #FFFF00000000",
+"X	c #FFFFA3A3A3A3",
+"o	c #FFFFFFFF0000",
+"O	c #FFFFD7D70000",
+"+	c #C1C1C6C6FFFF",
+"@	c #00000000FFFF",
+"#	c #8E8E9999FFFF",
+" ..X    X..         ",
+" .oO....Oo. ++      ",
+" .oooOOooo. @@@     ",
+" .oooooooo. +#@@    ",
+" .oooooooo.    @# # ",
+" .oooooooo.     @#+ ",
+" .OooooooO.   +@@@+ ",
+" X.oooooo.X     @@+ ",
+"  ..OooO..       @+ ",
+"   X.OO.X     ..  + ",
+"     ..     X.OO.X  ",
+"           ..OooO.. ",
+"          X.oooooo.X",
+"          .OooooooO.",
+"          .oooooooo.",
+"          .oooooooo.",
+"          .oooooooo.",
+"          .oooOOooo.",
+"          .oO....Oo.",
+"          ..X    X.."};
 /* XPM */
 static char * yp_xpm[] = {
 "20 20 7 1",
@@ -711,3 +726,35 @@ static char * pl_xpm[] = {
 "OX..++++.O.++++..X. ",
 " ++++++++.++++++++X ",
 "OOOOOOO@OOO@OOOOOO  "};
+/* XPM */
+static char * pm_xpm[] = {
+"20 20 9 1",
+" 	c #000000000000",
+".	c #808080808080",
+"X	c #FFFF00000000",
+"o	c #FFFFFFFFFFFF",
+"O	c #C0C0C0C0C0C0",
+"+	c #FFFFB7B7C1C1",
+"@	c #00000000FFFF",
+"#	c #B3B3CACAFFFF",
+"$	c #7F7F8E8EFFFF",
+"     .     XXXXXXXXX",
+"     o     XXXXXXXXX",
+"    OoO    ++XXXXXXX",
+"    oOo   Oooo+XXXXX",
+"   .o.o.   XXooX+XXX",
+"   Oo oO   XXXo+oXXX",
+"  .ooooo.  X+X+ooXXX",
+"  Oo   oO  XX+oooXXX",
+"  o.   .o  XXXXX+XXX",
+".ooo   ooo.@@@@@@@@@",
+"           ooooo#@@@",
+"XXXXXXXXX@@@o$@$$#@@",
+"XXXXXXXXX@@@o$@@@o$@",
+"XXXXXXXXX@@@o$@@$o@@",
+"XXXXXXXXX@@@oooo#@@@",
+"XXXXXXXXX@@@o$@@$o@@",
+"XXXXXXXXX@@@o$@@@o$@",
+"XXXXXXXXX@@@o$@$$#@@",
+"XXXXXXXXX@@ooooo#@@@",
+"XXXXXXXXX@@@@@@@@@@@"};
