@@ -1,12 +1,30 @@
-/*-------------------------------------------------------------------------*/
-/* xcircuit.c --- An X-windows program for drawing circuit diagrams	   */
-/* Copyright (c) 2001  Tim Edwards, Johns Hopkins University        	   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* xcircuit.c --- An X-windows program for drawing circuit diagrams	*/
+/* Copyright (c) 2001  R. Timothy Edwards				*/
+/*									*/
+/* This program is free software; you can redistribute it and/or modify */
+/* it under the terms of the GNU General Public License as published by */
+/* the Free Software Foundation; either version 2 of the License, or	*/
+/* (at your option) any later version.					*/
+/*									*/
+/* This program is distributed in the hope that it will be useful,	*/
+/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
+/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
+/* GNU General Public License for more details.				*/
+/*									*/
+/* You should have received a copy of the GNU General Public License	*/
+/* along with this program; if not, write to:				*/
+/*	Free Software Foundation, Inc.					*/
+/*	59 Temple Place, Suite 330					*/
+/*	Boston, MA  02111-1307  USA					*/
+/*									*/
+/* See file ./README for contact information				*/
+/*----------------------------------------------------------------------*/
 
-/*-------------------------------------------------------------------------*/
-/*      Uses the Xw widget set 						   */
-/*      written by Tim Edwards, 8/13/93    				   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/*      Uses the Xw widget set (see directory Xw)			*/
+/*      Xcircuit written by Tim Edwards beginning 8/13/93 		*/
+/*----------------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -48,9 +66,9 @@
 #define P_tmpdir TMPDIR
 #endif
 
-/*-------------------------------------------------------------------------*/
-/* Local includes							   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Local includes							*/
+/*----------------------------------------------------------------------*/
 
 #include "xcircuit.h"
 #include "cursors.h"
@@ -62,9 +80,9 @@
 /*----------------------------------------------------------------------*/
 #include "prototypes.h"
 
-/*-------------------------------------------------------------------------*/
-/* Local defines							   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Local defines							*/
+/*----------------------------------------------------------------------*/
 
 #define STIPPLES     8
 
@@ -73,9 +91,9 @@
 #include "xcircuit.xpm"
 #endif
 
-/*-------------------------------------------------------------------------*/
-/* Global Variable definitions						   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Global Variable definitions						*/
+/*----------------------------------------------------------------------*/
 
 typedef struct {
     CARD32 flags;
@@ -136,6 +154,7 @@ extern toolbarstruct ToolBar[];
 extern short maxbuttons, toolbuttons;
 extern Pixmap helppix;
 extern objectpair *pushlist;
+extern aliasptr aliastop;
 
 #ifdef DOUBLEBUFFER
 extern Pixmap dbuf;
@@ -151,9 +170,9 @@ XContext XUniqueContext()
 #endif
 /* End of bad hack. . . */
 
-/*-------------------------------------------------------------------------*/
-/* Initial Resource Management						   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Initial Resource Management						*/
+/*----------------------------------------------------------------------*/
 
 static XtResource resources[] = {
 
@@ -240,9 +259,9 @@ static XtResource resources[] = {
       XtOffset(ApplicationDataPtr, timeout), XtRString, "10"}
 };
 
-/*-------------------------------------------------------------------------*/
-/* Update the list of colors in the colormap				   */
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Update the list of colors in the colormap				*/
+/*----------------------------------------------------------------------*/
 
 void addtocolorlist(Widget button, int cvalue)
 {
@@ -2049,11 +2068,12 @@ int main(int argc, char *argv[])
 #ifdef HAVE_XPM
    areastruct.toolbar_on = True;
 #endif
-   
+
    /*---------------------------*/
    /* initialize user variables */
    /*---------------------------*/
 
+   aliastop = NULL;
    xobjs.pagelist = (Pagedata **) malloc(PAGES * sizeof(Pagedata *));
    for (page = 0; page < PAGES; page++) {
       xobjs.pagelist[page] = (Pagedata *) malloc(sizeof(Pagedata));
