@@ -700,6 +700,25 @@ typedef struct _matrix {
 
 #define PRESSTIME	150	/* milliseconds of push to be a "press" */
 
+/*----------------------------------------------------------------------*/
+/* object name alias structures						*/
+/*----------------------------------------------------------------------*/
+
+typedef struct _stringlist *slistptr;
+
+typedef struct _stringlist {
+   char *alias;
+   slistptr next;
+} stringlist;
+
+typedef struct _alias *aliasptr;
+
+typedef struct _alias {
+   objectptr baseobj;       /* pointer to object (actual name) */
+   slistptr aliases;    /* linked list of alias names */
+   aliasptr next;
+} alias;    
+
 /*----------------------------------------------------------------------*/
 /* structures for managing the popup prompt widgets 			*/
 /*----------------------------------------------------------------------*/
